# /packages/intranet-timesheet2-weekly/tcl/intranet-timesheet2-weekly-procs.tcl
#
# Copyright (C) 2014 ]project-open[
# 
# All rights reserved. Please check
# https://www.project-open.com/license/ for details.

ad_library {
    @author frank.bergmann@project-open.com
}

# ----------------------------------------------------------------------
# Portlets
# ---------------------------------------------------------------------


ad_proc -public im_timesheet_weekly_portlet {
    -project_id:required
} {
    Returns a HTML code with a Sencha timesheet entry portlet.
} {
    # Sencha check and permissions
    if {![im_sencha_extjs_installed_p]} { return "" }
    set current_user_id [ad_conn user_id]
    im_project_permissions $current_user_id $project_id view_p read_p write_p admin_p
    if {!$read_p} { return "" }
    if {![im_permission $current_user_id add_hours]} { return "" }
    im_sencha_extjs_load_libraries

    set params [list \
		    [list project_id $project_id] \
    ]

    set result [ad_parse_template -params $params "/packages/intranet-timesheet2-weekly/lib/timesheet-weekly"]
    return [string trim $result]
}




# ---------------------------------------------------------------------
# Permissions
# ---------------------------------------------------------------------

ad_proc -public im_hour_weekly_permissions {user_id weekly_id view_var read_var write_var admin_var} {
    Fill the "by-reference" variables read, write and admin
    with the permissions of $user_id on $weekly_id. 
    A user is allowed to see, modify and delete his own
    hour_weeklys.
} {
    upvar $view_var view
    upvar $read_var read
    upvar $write_var write
    upvar $admin_var admin

    set current_user_id $user_id
    set view 0
    set read 0
    set write 0
    set admin 0

    # Empty or bad weekly_id
    if {"" == $weekly_id || ![string is integer $weekly_id]} { return }

    # Get cached hour_weekly info
    if {![db_0or1row hour_weekly_info "
	select	*
	from	im_hour_weeklys i
	where	i.weekly_id = :weekly_id
    "]} {
	# Thic can happen if this procedure is called while the hour_weekly hasn't yet been created
	ns_log Error "im_hour_weekly_permissions: user_id=$user_id, weekly_id=$weekly_id: weekly_id not found"
	return
    }

    # The owner and administrators can always read and write
    if {$current_user_id == $user_id} {
	set view 1
	set read 1
	set write 1
	set admin 1
    }
}



ad_proc -public im_hour_weekly_nuke {
    {-current_user_id ""}
    rest_oid
} {
    Delete a hour weekly object. 
    This procedure is called from the intranet-rest interface
    after receiving a DELETE HTTP verb
} {
    # hour_weekly is not a real object, so we can just delete from the table
    db_dml delete_hour_weekly "delete from im_hour_weeklys where weekly_id = :rest_oid"
    return $rest_oid
}
